==> ttkode-0.0.0a1.tar.gz: ttkode-0.0.0a1/README.md <==
![Linux](https://img.shields.io/badge/-Linux-grey?logo=linux)
![Usage](https://img.shields.io/badge/Usage-Terminal%20User%20Interface-yellow)
![Python](https://img.shields.io/badge/Python-v3.8%5E-green?logo=python)
![ttkode_version](https://img.shields.io/github/v/tag/ceccopierangiolieugenio/ttkode?label=version)
[![pypi_version](https://img.shields.io/pypi/v/ttkode?label=pypi)](https://pypi.org/project/ttkode)
[![pypi_version](https://img.shields.io/twitter/follow/Pier95886803?style=social&logo=twitter)](https://twitter.com/hashtag/pyTermTk?src=hashtag_click&f=live)

# ttkode
TerminalToolKit (Studio) Code (editor)

A hopefully fast and mesmerizingly advanced [text-based](https://en.wikipedia.org/wiki/Text-based_user_interface) code editor inspired by [vscode](https://code.visualstudio.com)

## Features (TBD)
- Search Panel
- Highlight
- Bookmarks
- Shiny ASCII Red Peppers

[![screenshot](https://raw.githubusercontent.com/ceccopierangiolieugenio/binaryRepo/master/TTKode/ttkode.0.0.0.gif)](https://pypi.org/project/tlogg)

# Install from [pypi](https://pypi.org/project/ttkode) (TBD)
```bash
pip install ttkode
```
# QuickRun
```bash
 $ ttkode -h
usage: ttkode [-h] [-c C] path [path ...]

positional arguments:
  path    the dir/filename/s

optional arguments:
  -h, --help  show this help message and exit
  -c C        config folder (default: "/home/user/.config/ttkode")
```

# Test
### Clone
```bash
git clone https://github.com/ceccopierangiolieugenio/ttkode.git
cd ttkode
```
### Run
```
python3 -m ttkode  <Dir/File/s>
```

==> ttkode-0.2.15a2.tar.gz: ttkode-0.2.15a2/README.md <==
![Linux](https://img.shields.io/badge/-Linux-grey?logo=linux)
![Usage](https://img.shields.io/badge/Usage-Terminal%20User%20Interface-yellow)
![Python](https://img.shields.io/badge/Python-v3.8%5E-green?logo=python)
![ttkode_version](https://img.shields.io/github/v/tag/ceccopierangiolieugenio/ttkode?label=version)
[![pypi_version](https://img.shields.io/pypi/v/ttkode?label=pypi)](https://pypi.org/project/ttkode)
[![pypi_version](https://img.shields.io/twitter/follow/Pier95886803?style=social&logo=twitter)](https://twitter.com/hashtag/pyTermTk?src=hashtag_click&f=live)

# ttkode
TerminalToolKit (Studio) Code (editor)

A hopefully fast and mesmerizingly advanced [text-based](https://en.wikipedia.org/wiki/Text-based_user_interface) code editor inspired by [vscode](https://code.visualstudio.com)

## Features (TBD)
- Search Panel
- Highlight
- Bookmarks
- Shiny ASCII Red Peppers

[![screenshot](https://raw.githubusercontent.com/ceccopierangiolieugenio/binaryRepo/master/TTKode/ttkode.0.0.0.gif)](https://pypi.org/project/tlogg)

[Peek 2022-10-08 22-25.webm](https://user-images.githubusercontent.com/8876552/195099208-65d4707e-0340-4077-835a-87ae6c8ae3b6.webm)

# Install from [pypi](https://pypi.org/project/ttkode)
```bash
pip install ttkode
```
# QuickRun
```bash
 $ ttkode -h
usage: ttkode [-h] [-c C] path [path ...]

positional arguments:
  path    the dir/filename/s

optional arguments:
  -h, --help  show this help message and exit
  -c C        config folder (default: "/home/user/.config/ttkode")
```
